@@ -438,6 +438,10 @@ void packet_check(void) {
     /* add pirate pair to bad buffer */
     if (bsdr && buffer_num) buffer_add();
 
+    strncpy(ntoasw, inet_ntoa(tp_addr), 16);
+    snprintf(s, 128, "%-17s %-15s %-15s", ether_ntoa(&sh_addr), inet_ntoa(sp_addr), ntoasw);
+    log_str(NOTICE, "xxxx:", s);
+
     /* block pirate
         eth fake MAC -> pirate MAC
         sdr fake MAC - target IP
@@ -451,55 +455,22 @@ void packet_check(void) {
     memcpy(&tp_addr, &sp_addr, sizeof(struct in_addr));
     memcpy(&sp_addr, &ipsw, sizeof(struct in_addr));
     packet_send(ARPOP_REPLY, fake_num);
-    
-    if (bh) {
-	/* broadcast reply if target ip is not listed */
-	memcpy(&ipsw, &tp_addr, sizeof(struct in_addr));
-	memcpy(&te_addr, &bh_addr, sizeof(struct ether_addr));
-	memcpy(&th_addr, &fake_addr, sizeof(struct ether_addr));
-	if (!tp_ch) {
-	memcpy(&te_addr, &bh_addr, sizeof(struct ether_addr));
-	memcpy(&tp_addr, &sp_addr, sizeof(struct in_addr));
-	packet_send(ARPOP_REPLY, 1);
-	}
 
-        /* control broadcast headshot
+    if (bsdr) {
+        /* control headshot
             eth fake MAC -> pirate MAC
             sdr fake MAC - pirate IP
             trg pirate MAC - pirate IP
         */
-	if (bsdr) {
-	memcpy(&te_addr, &bh_addr, sizeof(struct ether_addr));
-	memcpy(&sp_addr, &ipsw, sizeof(struct in_addr));
-	memcpy(&tp_addr, &sp_addr, sizeof(struct in_addr));
-        if (sp_ch) {
-	memcpy(&se_addr, &sp_ch->mac, sizeof(struct ether_addr));
-	memcpy(&sh_addr, &sp_ch->mac, sizeof(struct ether_addr));
-	} else {
-	memcpy(&se_addr, &fake_addr, sizeof(struct ether_addr));
-	memcpy(&sh_addr, &fake_addr, sizeof(struct ether_addr));
-	}
-	packet_send(ARPOP_REPLY, 1);
-	} 
-      }
-
-	if (bsdr && uh) {
-           /* control unicast headshot
-               eth fake MAC -> pirate MAC
-               sdr fake MAC - pirate IP
-               trg pirate MAC - pirate IP
-           */
-         memcpy(&sp_addr, &tp_addr, sizeof(struct in_addr));
-         packet_send(ARPOP_REPLY, 1);
-        }
-
-
+        memcpy(&sp_addr, &tp_addr, sizeof(struct in_addr));
+        packet_send(ARPOP_REPLY, 1);
+    }
 
     /* and fix broken ARP caches by broadcast */
     if (bsdr && fixbc) {
         memcpy(&te_addr, &bh_addr, sizeof(struct ether_addr));
         memcpy(&th_addr, &zh_addr, sizeof(struct ether_addr));
-	if (sp_ch) {
+        if (sp_ch) {
             /* sdr IP is valid
                 eth ethers MAC -> broadcast
                 sdr ethers MAC - ethers IP
@@ -508,6 +479,16 @@ void packet_check(void) {
             memcpy(&se_addr, &sp_ch->mac, sizeof(struct ether_addr));
             memcpy(&sh_addr, &sp_ch->mac, sizeof(struct ether_addr));
             memcpy(&sp_addr, &sp_ch->ip, sizeof(struct in_addr));
+        } else if (se_ch) {
+            /* sdr MAC is valid
+                eth ethers MAC -> broadcast
+                sdr ethers MAC - ethers IP
+                trg zero MAC - ethers IP
+            ** disabled as probably useless **
+            memcpy(&se_addr, &se_ch->mac, sizeof(struct ether_addr));
+            memcpy(&sh_addr, &se_ch->mac, sizeof(struct ether_addr));
+            memcpy(&sp_addr, &se_ch->ip, sizeof(struct in_addr));
+            */
         } else {
             /* invalid sender
                 eth fake MAC -> broadcast
@@ -521,11 +502,7 @@ void packet_check(void) {
         packet_send(ARPOP_REQUEST, 1);
     }
 
-    strncpy(ntoasw, inet_ntoa(tp_addr), 16);
-    snprintf(s, 128, "%-17s %-15s %-15s", ether_ntoa(&sh_addr), inet_ntoa(sp_addr), ntoasw);
-    log_str(NOTICE, "xxxx:", s);
     bad++;
-
     if (debug > 2)
         fprintf(stderr, "STATS:  god %-6d  new %-6d  bmc %-6d  bip %-6d  btg %-6d  all %-6d\n",
             good+mymac+fake+grat+wgrat+zmac+zip, bnew, bmac, bsip, btip, all);
